# coding: utf-8

"""
    SEO Content Analysis API

    This API assesses the match between a URL or text content, a query, and an intent, using advanced SEO techniques.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.account_stats_api import AccountStatsApi


class TestAccountStatsApi(unittest.TestCase):
    """AccountStatsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = AccountStatsApi()

    def tearDown(self) -> None:
        pass

    def test_get_my_stats(self) -> None:
        """Test case for get_my_stats

        Get my Account statistics
        """
        pass


if __name__ == '__main__':
    unittest.main()
