# coding: utf-8

"""
    Analysis

    Analyse content using Linked Data and Knowledge Graphs.

    The version of the OpenAPI document: 1.0
    Contact: hello@wordlift.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from wordlift_client.api.o_auth2_authorized_clients_api import OAuth2AuthorizedClientsApi


class TestOAuth2AuthorizedClientsApi(unittest.TestCase):
    """OAuth2AuthorizedClientsApi unit test stubs"""

    def setUp(self) -> None:
        self.api = OAuth2AuthorizedClientsApi()

    def tearDown(self) -> None:
        pass

    def test_create_o_auth2_authorized_client(self) -> None:
        """Test case for create_o_auth2_authorized_client

        Create
        """
        pass

    def test_delete_o_auth2_authorized_client(self) -> None:
        """Test case for delete_o_auth2_authorized_client

        Delete
        """
        pass

    def test_get_o_auth2_authorized_client(self) -> None:
        """Test case for get_o_auth2_authorized_client

        Get
        """
        pass

    def test_list_o_auth2_authorized_clients(self) -> None:
        """Test case for list_o_auth2_authorized_clients

        List
        """
        pass

    def test_update_o_auth2_authorized_client(self) -> None:
        """Test case for update_o_auth2_authorized_client

        Update
        """
        pass


if __name__ == '__main__':
    unittest.main()
